@@ -262,7 +262,7 @@ static BOOL ffmpeg_open_context(FREERDP_DSP_CONTEXT* context)
 			break;
 
 		case AV_CODEC_ID_AAC:
-			context->context->profile = FF_PROFILE_AAC_MAIN;
+			context->context->profile = AV_PROFILE_AAC_MAIN;
 			break;
 
 		default:
